"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const INTERNAL_SERVER_ERROR = 500;
class ErrorHandler {
    constructor(logger) {
        this.logger = logger;
    }
    use(app) {
        app.use((error, request, response, next) => {
            const payload = getPayload(error);
            const status = getStatus(error);
            response.status(status);
            if (status !== INTERNAL_SERVER_ERROR) {
                response.json(payload);
            }
            logError(this.logger, request, error, status, payload);
            next(error);
        });
    }
}
exports.ErrorHandler = ErrorHandler;
function logError(logger, request, error, status, payload) {
    const data = Object.assign({
        request: {
            body: request.body,
            headers: request.headers,
            hostname: request.hostname,
            ip: request.ip,
            method: request.method,
            params: request.params,
            query: request.query,
            url: request.url,
        },
        stack: 'string' === typeof error.stack ? error.stack.split('\n') : error.stack,
        statusCode: status,
    }, payload);
    logger.error(error.message, data);
}
function getStatus(error) {
    return error.status || error.statusCode || INTERNAL_SERVER_ERROR;
}
function getPayload(error) {
    const data = {
        message: error.message,
    };
    switch (error.name) {
        case 'UnprocessableEntityError':
            data.fields = error.fields;
            break;
        case 'InternalServerError':
        case 'InvalidUpstreamResponse':
        case 'ParserError':
            data.info = error.info;
            break;
        default:
            break;
    }
    return {
        error: data,
    };
}
//# sourceMappingURL=ErrorHandler.js.map