"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const http_1 = __importDefault(require("http"));
const ErrorHandler_1 = require("./ErrorHandler");
class HttpServerBuilder {
    constructor(logger, options = {}) {
        this.logger = logger;
        this.options = options;
        this.errorHandler = new ErrorHandler_1.ErrorHandler(this.logger);
        this.routes = [];
        this.middlewares = [];
    }
    addMiddleware(middleware) {
        this.middlewares.push(middleware);
        return this;
    }
    addRoute(path, handler) {
        this.routes.push({ handler, path });
        return this;
    }
    getServer() {
        const app = express_1.default();
        setExpressOptions(app, this.options);
        applyMiddlewares(app, this.middlewares);
        applyRoutes(app, this.routes);
        applyErrorHandler(app, this.errorHandler);
        return http_1.default.createServer(app);
    }
}
exports.HttpServerBuilder = HttpServerBuilder;
function setExpressOptions(app, options) {
    const expressOptions = options.expressOptions || {};
    Object.keys(expressOptions).forEach(option => {
        app.set(option, expressOptions[option]);
    });
}
function applyErrorHandler(app, handler) {
    handler.use(app);
}
function applyMiddlewares(app, middlewares) {
    const currentEnv = app.get ? app.get('env') : process.env.NODE_ENV;
    middlewares.forEach(middleware => {
        if (middleware.isApplicable(currentEnv)) {
            app.use(middleware.handler());
        }
    });
}
function applyRoutes(app, routes) {
    routes.forEach(route => app.use(route.path, route.handler));
}
//# sourceMappingURL=HttpServerBuilder.js.map