"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Promise = require("bluebird");
const standard_http_error_1 = __importDefault(require("standard-http-error"));
class RequestHandler {
    static new() {
        return new RequestHandler();
    }
    static get status() {
        return standard_http_error_1.default;
    }
    constructor() {
        this.handler = () => {
            return Promise.resolve();
        };
        this.hooks = {
            postHandlers: [],
            preHandlers: [],
        };
        this.successStatus = standard_http_error_1.default.OK;
    }
    handle() {
        return (req, res, next) => {
            return this.executePreHandlerHooks(req, res)
                .then(() => this.handler(req, res, this))
                .then((data) => {
                res.body = data;
            })
                .then(() => this.executePostHandlerHooks(req, res))
                .then(() => this.sendResponse(res))
                .catch(next);
        };
    }
    setHandler(fn) {
        this.handler = fn;
        return this;
    }
    pre(fn) {
        this.hooks.preHandlers.push(fn);
        return this;
    }
    post(fn) {
        this.hooks.postHandlers.push(fn);
        return this;
    }
    plugin(fn) {
        fn(this);
        return this;
    }
    setSuccessStatus(statusCode) {
        this.successStatus = statusCode;
        return this;
    }
    sendResponse(res) {
        res.status(this.successStatus);
        if (res.body) {
            res.json(res.body);
        }
        else {
            res.end();
        }
    }
    executePreHandlerHooks(req, res) {
        return Promise.each(this.hooks.preHandlers, (preHandler) => {
            return Promise.try(() => preHandler(req, res, this));
        });
    }
    executePostHandlerHooks(req, res) {
        return Promise.each(this.hooks.postHandlers, (postHandler) => {
            return Promise.try(() => postHandler(req, res, this));
        });
    }
}
exports.RequestHandler = RequestHandler;
//# sourceMappingURL=RequestHandler.js.map