"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const cors_1 = __importDefault(require("cors"));
const standard_http_error_1 = __importDefault(require("standard-http-error"));
const AbstractExpressMiddleware_1 = require("./AbstractExpressMiddleware");
// exemple:
// set env CORS_FILTER to enable CORS only for specific origins
// CORS_FILTERS='\.?leadformance\.com(:?\d{4,5})?$;\.?lead\.fm(:?\d{4,5})?$;localhost(:?\d{4,5})?$'
const DEFAULT_CONFIG = {
    excluded: [],
    filters: '',
};
class CorsMiddleware extends AbstractExpressMiddleware_1.AbstractExpressMiddleware {
    constructor(config = DEFAULT_CONFIG) {
        super(config);
        this._config = Object.assign({}, DEFAULT_CONFIG, { options: this.corsProcessing.bind(this) }, config);
    }
    get config() {
        return this._config;
    }
    handler() {
        return this.unless(this.config.excluded, cors_1.default(this.config.options));
    }
    corsProcessing(req, callback) {
        if (isOptionsRequest(req) || isRequestWithoutOrigin(req)) {
            return callback(null, { origin: true, credentials: true });
        }
        const whiteList = [
            ...allowedOriginsFromConfig(this.config.filters),
            ...allowedOriginsFromSSO(req),
        ];
        if (isOriginWhitelisted(req, whiteList)) {
            return callback(null, { origin: true, credentials: true });
        }
        callback(new standard_http_error_1.default(standard_http_error_1.default.UNAUTHORIZED, `cross-origin request from ${origin(req)} is not allowed`), null);
    }
}
exports.CorsMiddleware = CorsMiddleware;
function allowedOriginsFromConfig(filters) {
    const corsFiltersFromEnv = filters || process.env.CORS_FILTERS; // fallback to env variable for backward compatibility
    return corsFiltersFromEnv ? corsFiltersFromEnv.split(';') : [];
}
function allowedOriginsFromSSO(req) {
    const replaceCharForRegex = (pattern) => pattern.replace(/\./g, '\\.').replace(/\*/g, '.*');
    return tokenAllowedOrigins(req).map(replaceCharForRegex);
}
function isOptionsRequest(req) {
    return req.method === 'OPTIONS';
}
function isOriginWhitelisted(req, whiteList = []) {
    return whiteList.some(item => new RegExp(item).test(origin(req) || ''));
}
function isRequestWithoutOrigin(req) {
    return typeof origin(req) === 'undefined';
}
function origin(req) {
    return req.header('Origin');
}
function tokenAllowedOrigins(req) {
    return (req.user && req.user['allowed-origins']) || [];
}
//# sourceMappingURL=CorsMiddleware.js.map