"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_jwt_1 = __importDefault(require("express-jwt"));
const AbstractExpressMiddleware_1 = require("./AbstractExpressMiddleware");
const DEFAULT_CONFIG = {
    excluded: [],
    secret: '',
};
class SsoMiddleware extends AbstractExpressMiddleware_1.AbstractExpressMiddleware {
    constructor(config = DEFAULT_CONFIG) {
        super(config);
        this._config = Object.assign({}, DEFAULT_CONFIG, config, { options: Object.assign({}, config.options, { getToken, secret: base64toPem(config.secret) }) });
    }
    handler() {
        // The following is necessary to prevent TSC to complain.
        const jwtOptions = this.config.options;
        return express_jwt_1.default(jwtOptions).unless({ path: this.config.excluded });
    }
    get config() {
        return this._config;
    }
}
SsoMiddleware.NAME = 'sso';
exports.SsoMiddleware = SsoMiddleware;
/**
 * Splits key by lines of 64 characters and encloses it in BEGIN/END PUBLIC KEY comments according to PEM format
 * @param base64 key in base64
 * @returns {string} valid PEM key
 */
function base64toPem(base64) {
    const lines = base64.match(/.{1,64}/g) || [];
    const formattedKey = lines.join('\n');
    return `-----BEGIN PUBLIC KEY-----\n${formattedKey}\n-----END PUBLIC KEY-----`;
}
function getToken(req) {
    let token = null;
    if (req.headers && req.headers.authorization) {
        // const [authType, authValue] = req.headers.authorization.split(' ');
        const [authType, authValue] = splitAuthorizationHeader(req.headers.authorization);
        if ('bearer' === authType.toLowerCase()) {
            token = authValue;
        }
    }
    else if (req.query && req.query.access_token) {
        token = req.query.access_token;
    }
    addTokenToExpressRequest(req, token);
    return token;
}
function splitAuthorizationHeader(headerValue) {
    return 'string' === typeof headerValue ? headerValue.split(' ') : headerValue;
}
function addTokenToExpressRequest(req, token) {
    req.token = token;
}
//# sourceMappingURL=SsoMiddleware.js.map