"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const VersioningPluginBuilder_1 = require("./VersioningPluginBuilder");
class VersioningManager {
    constructor(options) {
        this.validateOptions(options);
        this.supportedApplications = new Set(options.supportedApplications);
        this.supportedVersions = new Set(options.supportedVersions);
    }
    newRequestHandlerPluginBuilder() {
        return new VersioningPluginBuilder_1.VersioningPluginBuilder(this.supportedApplications, this.supportedVersions);
    }
    validateOptions(options) {
        const hasValidSupportedVersions = 'supportedVersions' in options &&
            Array.isArray(options.supportedVersions) &&
            options.supportedVersions.length > 0 &&
            options.supportedVersions.every(version => 'string' === typeof version);
        if (!hasValidSupportedVersions) {
            throw new TypeError('Expect options "supportedVersions" to be an array of string');
        }
        const hasValidSupportedApplications = 'supportedApplications' in options &&
            Array.isArray(options.supportedApplications) &&
            options.supportedApplications.length > 0 &&
            options.supportedApplications.every(application => 'string' === typeof application);
        if (!hasValidSupportedApplications) {
            throw new TypeError('Expect options "supportedApplications" to be an array of string');
        }
    }
}
exports.VersioningManager = VersioningManager;
//# sourceMappingURL=VersioningManager.js.map