"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluebird_1 = __importDefault(require("bluebird"));
const socket_io_1 = __importDefault(require("socket.io"));
class SocketServerBuilder {
    constructor(httpServer) {
        this._httpServer = httpServer;
        this.routes = [];
        this.middlewares = [];
    }
    addMiddleware(middleware) {
        this.middlewares.push(middleware);
        return this;
    }
    addRoute(router, path = '') {
        this.routes.push({ path, router });
        return this;
    }
    getServer() {
        const server = socket_io_1.default(this._httpServer);
        applyMiddlewares(server, this.middlewares);
        applySocketRoutes(server, this.routes);
        return server;
    }
    get httpServer() {
        return this._httpServer;
    }
}
exports.SocketServerBuilder = SocketServerBuilder;
function applyMiddlewares(server, middlewares) {
    middlewares.forEach(middleware => server.use(middleware.handler()));
}
function applySocketRoutes(server, routes) {
    routes.forEach(({ path, router }) => {
        server.use((socket, next) => bluebird_1.default.try(() => router.register(socket, path)).asCallback(next));
    });
}
//# sourceMappingURL=SocketServerBuilder.js.map