"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluebird_1 = __importDefault(require("bluebird"));
const AbstractSocketMiddleware_1 = require("./AbstractSocketMiddleware");
class SocketErrorLoggerMiddleware extends AbstractSocketMiddleware_1.AbstractSocketMiddleware {
    constructor(logger, config = {}) {
        super(config);
        this._config = config;
        this.logger = logger;
    }
    handler() {
        return (socket, next) => {
            return bluebird_1.default.try(() => {
                socket.on('error', error => {
                    this.logger.error('Socket error', {
                        error: error.message,
                        socketId: socket.id,
                    });
                });
            }).asCallback(next);
        };
    }
    get config() {
        return this._config;
    }
}
SocketErrorLoggerMiddleware.NAME = 'socketErrorLogger';
exports.SocketErrorLoggerMiddleware = SocketErrorLoggerMiddleware;
//# sourceMappingURL=SocketErrorLoggerMiddleware.js.map