"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluebird_1 = __importDefault(require("bluebird"));
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const lodash_get_1 = __importDefault(require("lodash.get"));
const standard_http_error_1 = __importDefault(require("standard-http-error"));
const AbstractSocketMiddleware_1 = require("./AbstractSocketMiddleware");
const DEFAULT_CONFIG = {
    algorithms: ['RS256'],
    secret: '',
};
class SocketSsoMiddleware extends AbstractSocketMiddleware_1.AbstractSocketMiddleware {
    constructor(config = DEFAULT_CONFIG) {
        super(config);
        this._config = Object.assign({}, DEFAULT_CONFIG, { secret: base64toPem(config.secret) });
    }
    handler() {
        return (socket, next) => {
            socket.auth = false;
            socket.token = lodash_get_1.default(socket, 'handshake.query.token', null);
            return bluebird_1.default.try(() => {
                return jsonwebtoken_1.default.verify(socket.token, this.config.secret, this.config);
            })
                .then(user => {
                socket.auth = true;
                socket.user = user;
            })
                .tapCatch(e => {
                // Add data to be sent to client
                e.data = {
                    message: e.message,
                    statusCode: standard_http_error_1.default.UNAUTHORIZED,
                };
            })
                .asCallback(next);
        };
    }
    get config() {
        return this._config;
    }
}
SocketSsoMiddleware.NAME = 'socketSso';
exports.SocketSsoMiddleware = SocketSsoMiddleware;
/**
 * Splits key by lines of 64 characters and encloses it in BEGIN/END PUBLIC KEY comments according to PEM format
 * @param base64 key in base64
 * @returns {string} valid PEM key
 */
function base64toPem(base64) {
    const lines = base64.match(/.{1,64}/g) || [];
    const formattedKey = lines.join('\n');
    return `-----BEGIN PUBLIC KEY-----\n${formattedKey}\n-----END PUBLIC KEY-----`;
}
//# sourceMappingURL=SocketSsoMiddleware.js.map