/// <reference types="node" />
import { Server } from 'http';
import { SuperTest, Test } from 'supertest';
export declare class HttpClientHelper {
    private httpClient;
    /**
     * Get the currently configured Http Client
     * @returns {supertest.SuperTest<supertest.Test>}
     */
    get(): SuperTest<Test>;
    /**
     * Setup an Http Client for the given endpoint url
     * @param {string} url : endpoint url
     * @returns {PromiseLike<void>}
     */
    setup(url: string): Promise<void>;
    /**
     * Initialize Server for Jest worker.
     * Port will be configured dynamically since jest has multiple workers
     * @param {"http".Server} httpServer
     * @param {(port: number, endpointUrl: string) => void} configurationHandler : Called when a port is dynamically chosen
     */
    initHttpServerForJest(httpServer: Server, configurationHandler: (port: number, endpointUrl: string) => void): void;
}
export declare const httpClientHelper: HttpClientHelper;
