"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bluebird_1 = __importDefault(require("bluebird"));
const get_port_1 = __importDefault(require("get-port"));
const supertest_1 = require("supertest");
class HttpClientHelper {
    constructor() {
        this.httpClient = null;
    }
    /**
     * Get the currently configured Http Client
     * @returns {supertest.SuperTest<supertest.Test>}
     */
    get() {
        return this.httpClient;
    }
    /**
     * Setup an Http Client for the given endpoint url
     * @param {string} url : endpoint url
     * @returns {PromiseLike<void>}
     */
    setup(url) {
        return __awaiter(this, void 0, void 0, function* () {
            this.httpClient = yield supertest_1.agent(url);
        });
    }
    /**
     * Initialize Server for Jest worker.
     * Port will be configured dynamically since jest has multiple workers
     * @param {"http".Server} httpServer
     * @param {(port: number, endpointUrl: string) => void} configurationHandler : Called when a port is dynamically chosen
     */
    initHttpServerForJest(httpServer, configurationHandler) {
        // Init Http server and the matching client
        beforeAll(() => {
            return get_port_1.default().then((port) => {
                configurationHandler(port, `http://localhost:${port}`);
                return bluebird_1.default.fromCallback(callback => httpServer.listen(port, callback), { multiArgs: true });
            });
        });
        afterAll(() => {
            return bluebird_1.default.fromCallback(callback => httpServer.close(callback));
        });
    }
}
exports.HttpClientHelper = HttpClientHelper;
exports.httpClientHelper = new HttpClientHelper();
//# sourceMappingURL=httpClientHelper.js.map